Documentation
¶
Overview ¶
Package classify suggests Tags that are likely to be a match for news Items.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Advisor ¶
type Advisor struct {
// contains filtered or unexported fields
}
Advisor suggests Tags for Items, based on existing tagging.
func (*Advisor) Reset ¶
Reset discards the Advisor's training state and trains it from scratch on the tagged Items in the Database.
type Suggestion ¶
Suggestion is the ID of a Tag and the score calculated by the Advisor.
Click to show internal directories.
Click to hide internal directories.